# Contributing Guidelines

Contributions to Riroriro are welcome. If you have an issue, a code contribution or a documentation contribution, thanks for helping to improve Riroriro!

## Issues

When creating an issue report, please be as specific as possible when describing how to reproduce an issue, and include both the intended/expected result and what you are actually getting.

## Code contributions

If you are performing a bugfix or adding a feature, please fork the repository, create a dedicated branch for your contribution and create a pull request when you are done.

## Documentation contributions

Riroriro has documentation written in reStructuredText, which can be found in the docs/ directory. If you have an improvement for the documentation, please put it on a dedicated branch as with code contributions. If you are adding a new feature in code contributions, you are encouraged to add documentation about it in the docs/ directory.